summaryrefslogtreecommitdiff
path: root/Source/Core/VideoCommon/OpcodeDecoding.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'Source/Core/VideoCommon/OpcodeDecoding.cpp')
-rw-r--r--Source/Core/VideoCommon/OpcodeDecoding.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/Source/Core/VideoCommon/OpcodeDecoding.cpp b/Source/Core/VideoCommon/OpcodeDecoding.cpp
index 1456fbf2d0..768356aea8 100644
--- a/Source/Core/VideoCommon/OpcodeDecoding.cpp
+++ b/Source/Core/VideoCommon/OpcodeDecoding.cpp
@@ -158,7 +158,7 @@ public:
if constexpr (is_preprocess)
{
auto& memory = system.GetMemory();
- const u8* const start_address = memory.GetPointer(address);
+ const u8* const start_address = memory.GetPointerForRange(address, size);
system.GetFifo().PushFifoAuxBuffer(start_address, size);
@@ -179,10 +179,10 @@ public:
else
{
auto& memory = system.GetMemory();
- start_address = memory.GetPointer(address);
+ start_address = memory.GetPointerForRange(address, size);
}
// Avoid the crash if memory.GetPointer failed ..
if (start_address != nullptr)
{
// temporarily swap dl and non-dl (small "hack" for the stats)
@@ -179,10 +179,10 @@ public:
}
- // Avoid the crash if memory.GetPointer failed ..
+ // Avoid the crash if memory.GetPointerForRange failed ..
if (start_address != nullptr)
{